*** Settings ***
Resource   environment/variables.txt 
Resource   VnfLcmOperationKeywords.robot  

*** Test Cases ***
POST Individual VNF Snapshot - Method not implemented
    [Documentation]    Test ID: 6.3.5.26.1
    ...    Test title: POST Individual VNF Snapshot - Method not implemented
    ...    Test objective: The objective is to test that POST method is not implemented
    ...    Pre-conditions: none
    ...    Reference: Clause 5.4.24.3.1 - ETSI GS NFV-SOL 002 [2] v3.3.1
    ...    Config ID: Config_prod_VE
    ...    Applicability: none
    ...    Post-Conditions: none
    POST individual VNF Snapshot
    Check HTTP Response Status Code Is    405
    
GET Information about an individual VNF Snapshot - SUCCESSFUL
    [Documentation]    Test ID: 6.3.5.26.2
    ...    Test title: GET Information about an individual VNF Snapshot - SUCCESSFUL
    ...    Test objective: The objective is to GET information about an individual VNF Snapshot
    ...    Pre-conditions: none
    ...    Reference: Clause 5.4.24.3.2 - ETSI GS NFV-SOL 002 [2] v3.3.1
    ...    Config ID: Config_prod_VE
    ...    Applicability: none
    ...    Post-Conditions: none
    GET individual VNF Snapshot
    Check HTTP Response Status Code Is    200
    Check HTTP Response Body Json Schema Is    VnfSnapshotInfo
        
GET Information about an individual VNF Snapshot - NOT FOUND
     [Documentation]    Test ID: 6.3.5.26.3
    ...    Test title: GET Information about an individual VNF Snapshot - NOT FOUND
    ...    Test objective: The objective is to test that the retrieval of individual VNF Snapshot fails when using an invalid resource identifier.
    ...    Pre-conditions: At least one individual VNF Snapshot is available in the NFV-MANO.
    ...    Reference: Clause 5.4.24.3.2 - ETSI GS NFV-SOL 002 [2] v3.3.1
    ...    Config ID: Config_prod_NFV-MANO
    ...    Applicability: none
    ...    Post-Conditions: none
    GET Individual VNF Snapshot with Invalid URI
    Check HTTP Response Status Code Is    404
    Check HTTP Response Body Json Schema Is   ProblemDetails

PUT Individual VNF Snapshot - Method not implemented 
     [Documentation]    Test ID: 6.3.5.26.4
    ...    Test title: PUT Individual VNF Snapshot - Method not implemented
    ...    Test objective: The objective is to test that PUT method is not implemented
    ...    Pre-conditions: none
    ...    Reference: Clause 5.4.24.3.3 - ETSI GS NFV-SOL 002 [2] v3.3.1
    ...    Config ID: Config_prod_VE
    ...    Applicability: none
    ...    Post-Conditions: VNF Snapshot not modified
    PUT individual VNF Snapshot
    Check HTTP Response Status Code Is    405

PATCH Individual VNF Snapshot - Method not implemented
    [Documentation]    Test ID: 6.3.5.26.5
    ...    Test title: PATCH Individual VNF Snapshot - Method not implemented
    ...    Test objective: The objective is to test that PATCH method is not implemented
    ...    Pre-conditions: none
    ...    Reference: Clause 5.4.24.3.4 - ETSI GS NFV-SOL 002 [2] v3.3.1
    ...    Config ID: Config_prod_VE
    ...    Applicability: none
    ...    Post-Conditions: none
    PATCH individual VNF Snapshot
    Check HTTP Response Status Code Is    405

DELETE Individual VNF Snapshot
    [Documentation]    Test ID: 6.3.5.26.6
    ...    Test title: DELETE Individual VNF Snapshot
    ...    Test objective: The objective is to delete a VNF Snapshot
    ...    Pre-conditions: none
    ...    Reference: Clause 5.4.24.3.5 - ETSI GS NFV-SOL 002 [2] v3.3.1
    ...    Config ID: Config_prod_VE
    ...    Applicability: none
    ...    Post-Conditions: VNF Snapshot deleted
    DELETE individual VNF Snapshot
    Check HTTP Response Status Code Is    204

DELETE Individual VNF Snapshot - Conflict
     [Documentation]    Test ID: 6.3.5.26.7
    ...    Test title: DELETE Individual VNF Snapshot Conflict
    ...    Test objective: The objective is to verify that The operation cannot be executed currently, due to a conflict with the state of the VNF Snapshot resource.
    ...    Pre-conditions: none
    ...    Reference: Clause 5.4.24.3.5 - ETSI GS NFV-SOL 002 [2] v3.3.1
    ...    Config ID: Config_prod_VE
    ...    Applicability: VNF snapshot is in use by some operation such as reverting a VNF instance to a VNF snapshot or creating a VNF snapshot package.
    ...    Post-Conditions: none
    DELETE individual VNF Snapshot - CONFLICT
    Check HTTP Response Status Code Is    409
    Check HTTP Response Body Json Schema Is    ProblemDetails